==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmReleaseFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HelmReleaseFluent<A extends HelmReleaseFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public HelmReleaseFluent.MetadataNested<A> withNewMetadata();
  public HelmReleaseFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public HelmReleaseFluent.MetadataNested<A> editMetadata();
  public HelmReleaseFluent.MetadataNested<A> editOrNewMetadata();
  public HelmReleaseFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildRepo instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmReleaseRepo getRepo();
  public HelmReleaseRepo buildRepo();
  public A withRepo(HelmReleaseRepo repo);
  public Boolean hasRepo();
  public HelmReleaseFluent.RepoNested<A> withNewRepo();
  public HelmReleaseFluent.RepoNested<A> withNewRepoLike(HelmReleaseRepo item);
  public HelmReleaseFluent.RepoNested<A> editRepo();
  public HelmReleaseFluent.RepoNested<A> editOrNewRepo();
  public HelmReleaseFluent.RepoNested<A> editOrNewRepoLike(HelmReleaseRepo item);
  public A addToSpec(String key,Object value);
  public A addToSpec(Map<String,Object> map);
  public A removeFromSpec(String key);
  public A removeFromSpec(Map<String,Object> map);
  public Map<String,Object> getSpec();
  public <K,V>A withSpec(Map<String,Object> spec);
  public Boolean hasSpec();
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmAppStatus getStatus();
  public HelmAppStatus buildStatus();
  public A withStatus(HelmAppStatus status);
  public Boolean hasStatus();
  public HelmReleaseFluent.StatusNested<A> withNewStatus();
  public HelmReleaseFluent.StatusNested<A> withNewStatusLike(HelmAppStatus item);
  public HelmReleaseFluent.StatusNested<A> editStatus();
  public HelmReleaseFluent.StatusNested<A> editOrNewStatus();
  public HelmReleaseFluent.StatusNested<A> editOrNewStatusLike(HelmAppStatus item);
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<HelmReleaseFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface RepoNested<N> extends Nested<N>,HelmReleaseRepoFluent<HelmReleaseFluent.RepoNested<N>>{
    public N and();
    public N endRepo();
    
  }
  public interface StatusNested<N> extends Nested<N>,HelmAppStatusFluent<HelmReleaseFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmReleaseFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HelmReleaseFluent<A extends HelmReleaseFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public HelmReleaseFluent.MetadataNested<A> withNewMetadata();
  public HelmReleaseFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public HelmReleaseFluent.MetadataNested<A> editMetadata();
  public HelmReleaseFluent.MetadataNested<A> editOrNewMetadata();
  public HelmReleaseFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildRepo instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmReleaseRepo getRepo();
  public HelmReleaseRepo buildRepo();
  public A withRepo(HelmReleaseRepo repo);
  public Boolean hasRepo();
  public HelmReleaseFluent.RepoNested<A> withNewRepo();
  public HelmReleaseFluent.RepoNested<A> withNewRepoLike(HelmReleaseRepo item);
  public HelmReleaseFluent.RepoNested<A> editRepo();
  public HelmReleaseFluent.RepoNested<A> editOrNewRepo();
  public HelmReleaseFluent.RepoNested<A> editOrNewRepoLike(HelmReleaseRepo item);
  public A addToSpec(String key,Object value);
  public A addToSpec(Map<String,Object> map);
  public A removeFromSpec(String key);
  public A removeFromSpec(Map<String,Object> map);
  public Map<String,Object> getSpec();
  public <K,V>A withSpec(Map<String,Object> spec);
  public Boolean hasSpec();
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmAppStatus getStatus();
  public HelmAppStatus buildStatus();
  public A withStatus(HelmAppStatus status);
  public Boolean hasStatus();
  public HelmReleaseFluent.StatusNested<A> withNewStatus();
  public HelmReleaseFluent.StatusNested<A> withNewStatusLike(HelmAppStatus item);
  public HelmReleaseFluent.StatusNested<A> editStatus();
  public HelmReleaseFluent.StatusNested<A> editOrNewStatus();
  public HelmReleaseFluent.StatusNested<A> editOrNewStatusLike(HelmAppStatus item);
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<HelmReleaseFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface RepoNested<N> extends Nested<N>,HelmReleaseRepoFluent<HelmReleaseFluent.RepoNested<N>>{
    public N and();
    public N endRepo();
    
  }
  public interface StatusNested<N> extends Nested<N>,HelmAppStatusFluent<HelmReleaseFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
